@@ -1,3 +1,3 @@
 package t::lib::B;
-use c3;
-1;
\ No newline at end of file
+use Class::C3;
+1;
